# Kudubot

|master|develop|
|:----:|:-----:|
|[![build status](https://gitlab.namibsun.net/namibsun/python/kudubot/badges/master/build.svg)](https://gitlab.namibsun.net/namibsun/python/kudubot/commits/master)|[![build status](https://gitlab.namibsun.net/namibsun/python/kudubot/badges/develop/build.svg)](https://gitlab.namibsun.net/namibsun/python/kudubot/commits/develop)|

![Logo](resources/logo/logo-readme.png)

Kudubot is a chat bot framework designed to work with arbitrary messaging
services based on
[bokkichat](https://gitlab.namibsun.net/namibsun/python/bokkichat)
connections.

## Further Information

* [Changelog](CHANGELOG)
* [License (GPLv3)](LICENSE)
* [Gitlab](https://gitlab.namibsun.net/namibsun/python/kudubot)
* [Github](https://github.com/namboy94/kudubot)
* [Progstats](https://progstats.namibsun.net/projects/kudubot)
* [PyPi](https://pypi.org/project/kudubot)
